"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../constants");
var BoxCornerStyle;
(function (BoxCornerStyle) {
    BoxCornerStyle[BoxCornerStyle["Square"] = 0] = "Square";
    BoxCornerStyle[BoxCornerStyle["Rounded"] = 1] = "Rounded";
})(BoxCornerStyle = exports.BoxCornerStyle || (exports.BoxCornerStyle = {}));
class Box {
    constructor(topRow, leftColumn, bottomRow, rightColumn, cornerStyle, lineStyle) {
        this._topRow = topRow;
        this._leftColumn = leftColumn;
        this._bottomRow = bottomRow;
        this._rightColumn = rightColumn;
        this._canvasX = leftColumn * constants_1.Constants.densityX;
        this._canvasY = topRow * constants_1.Constants.densityY;
        this._canvasWidth = (rightColumn - leftColumn + 1) * constants_1.Constants.densityX;
        this._canvasHeight = (bottomRow - topRow + 1) * constants_1.Constants.densityY;
        this._cornerStyle = cornerStyle;
        this._lineStyle = lineStyle;
    }
    get rightColumn() {
        return this._rightColumn;
    }
    get bottomRow() {
        return this._bottomRow;
    }
    get leftColumn() {
        return this._leftColumn;
    }
    get topRow() {
        return this._topRow;
    }
    get canvasHeight() {
        return this._canvasHeight;
    }
    get canvasWidth() {
        return this._canvasWidth;
    }
    get canvasY() {
        return this._canvasY;
    }
    get canvasX() {
        return this._canvasX;
    }
    get cornerStyle() {
        return this._cornerStyle;
    }
    get lineStyle() {
        return this._lineStyle;
    }
}
exports.Box = Box;
(function (Box) {
    class Builder {
        constructor(topRow, leftColumn, bottomRow, rightColumn, cornerStyle, lineStyle) {
            this._topRow = topRow;
            this._leftColumn = leftColumn;
            this._bottomRow = bottomRow;
            this._rightColumn = rightColumn;
            this._cornerStyle = cornerStyle;
            this._lineStyle = lineStyle;
        }
        static from(box) {
            return new Builder(box.topRow, box.leftColumn, box.bottomRow, box.rightColumn, box.cornerStyle, box.lineStyle);
        }
        build() {
            return new Box(this._topRow, this._leftColumn, this._bottomRow, this._rightColumn, this._cornerStyle, this._lineStyle);
        }
        topRow(value) {
            this._topRow = value;
            return this;
        }
        leftColumn(value) {
            this._leftColumn = value;
            return this;
        }
        bottomRow(value) {
            this._bottomRow = value;
            return this;
        }
        rightColumn(value) {
            this._rightColumn = value;
            return this;
        }
        cornerStyle(value) {
            this._cornerStyle = value;
            return this;
        }
        lineStyle(value) {
            this._lineStyle = value;
            return this;
        }
    }
    Box.Builder = Builder;
})(Box = exports.Box || (exports.Box = {}));
//# sourceMappingURL=box.js.map