export declare enum ConnectorDirection {
    Horizontal = 0,
    Vertical = 1
}
export declare enum ConnectorTipDirection {
    North = 0,
    South = 1,
    East = 2,
    West = 3
}
export declare enum ConnectorTipStyle {
    Flat = 0,
    Arrow = 1
}
export declare enum LineStyle {
    Continuous = 0,
    Dashed = 1,
    Dotted = 2
}
export declare type GridPoint = {
    row: number;
    column: number;
};
export declare type GridEdge = {
    start: GridPoint;
    end: GridPoint;
};
export interface VerticalConnector {
    verticalEdge: GridEdge;
    horizontalEdge: null;
    intersectionPoint: null;
}
export interface HorizontalConnector {
    verticalEdge: null;
    horizontalEdge: GridEdge;
    intersectionPoint: null;
}
export interface PointConnector {
    verticalEdge: null;
    horizontalEdge: null;
    intersectionPoint: GridPoint;
}
export interface EdgedConnector {
    verticalEdge: GridEdge;
    horizontalEdge: GridEdge;
    intersectionPoint: GridPoint;
}
export declare function isIntersectedConnector(object: ConnectorType): object is IntersectedConnector;
export declare function isVerticalConnector(object: ConnectorType): object is VerticalConnector;
export declare function isHorizontalConnector(object: ConnectorType): object is HorizontalConnector;
export declare function isEdgedConnector(object: ConnectorType): object is EdgedConnector;
export declare function isPointConnector(object: ConnectorType): object is PointConnector;
export declare type IntersectedConnector = PointConnector | EdgedConnector;
export declare type ConnectorType = VerticalConnector | HorizontalConnector | PointConnector | EdgedConnector;
export declare function createConnectorType(horizontalEdgeStartPoint: GridPoint, intersectionPoint: GridPoint, verticalEdgeStartPoint: GridPoint): ConnectorType;
export declare class Connector {
    private readonly _connectorType;
    private readonly _lineStyle;
    private readonly _horizontalTipStyle;
    private readonly _verticalTipStyle;
    static createByStartPoints(horizontalEdgeStartPoint: GridPoint, intersectionPoint: GridPoint, verticalEdgeStartPoint: GridPoint, lineStyle?: LineStyle, horizontalTipStyle?: ConnectorTipStyle, verticalTipStyle?: ConnectorTipStyle): Connector;
    constructor(connectorType: ConnectorType, lineStyle?: LineStyle, horizontalTipStyle?: ConnectorTipStyle, verticalTipStyle?: ConnectorTipStyle);
    get verticalEdge(): GridEdge | null;
    get horizontalEdge(): GridEdge | null;
    get intersectionPoint(): GridPoint | null;
    get connectorType(): ConnectorType;
    get lineStyle(): LineStyle;
    get horizontalTipStyle(): ConnectorTipStyle;
    get verticalTipStyle(): ConnectorTipStyle;
}
export declare namespace Connector {
    class Builder {
        protected _connectorType: ConnectorType;
        protected _lineStyle: LineStyle;
        protected _horizontalTipStyle: ConnectorTipStyle;
        protected _verticalTipStyle: ConnectorTipStyle;
        protected constructor(connectorType: ConnectorType, lineStyle: LineStyle, horizontalTipStyle: ConnectorTipStyle, verticalTipStyle: ConnectorTipStyle);
        static from(connector: Connector): Builder;
        build(): Connector;
        connectorType(value: ConnectorType): this;
        lineStyle(value: LineStyle): this;
        horizontalTipStyle(value: ConnectorTipStyle): this;
        verticalTipStyle(value: ConnectorTipStyle): this;
    }
}
