"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ConnectorDirection;
(function (ConnectorDirection) {
    ConnectorDirection[ConnectorDirection["Horizontal"] = 0] = "Horizontal";
    ConnectorDirection[ConnectorDirection["Vertical"] = 1] = "Vertical";
})(ConnectorDirection = exports.ConnectorDirection || (exports.ConnectorDirection = {}));
var ConnectorTipDirection;
(function (ConnectorTipDirection) {
    ConnectorTipDirection[ConnectorTipDirection["North"] = 0] = "North";
    ConnectorTipDirection[ConnectorTipDirection["South"] = 1] = "South";
    ConnectorTipDirection[ConnectorTipDirection["East"] = 2] = "East";
    ConnectorTipDirection[ConnectorTipDirection["West"] = 3] = "West";
})(ConnectorTipDirection = exports.ConnectorTipDirection || (exports.ConnectorTipDirection = {}));
var ConnectorTipStyle;
(function (ConnectorTipStyle) {
    ConnectorTipStyle[ConnectorTipStyle["Flat"] = 0] = "Flat";
    ConnectorTipStyle[ConnectorTipStyle["Arrow"] = 1] = "Arrow";
})(ConnectorTipStyle = exports.ConnectorTipStyle || (exports.ConnectorTipStyle = {}));
var LineStyle;
(function (LineStyle) {
    LineStyle[LineStyle["Continuous"] = 0] = "Continuous";
    LineStyle[LineStyle["Dashed"] = 1] = "Dashed";
    LineStyle[LineStyle["Dotted"] = 2] = "Dotted";
})(LineStyle = exports.LineStyle || (exports.LineStyle = {}));
function isIntersectedConnector(object) {
    return object.intersectionPoint !== null;
}
exports.isIntersectedConnector = isIntersectedConnector;
function isVerticalConnector(object) {
    return object.verticalEdge !== null && object.horizontalEdge === null;
}
exports.isVerticalConnector = isVerticalConnector;
function isHorizontalConnector(object) {
    return object.horizontalEdge !== null && object.verticalEdge === null;
}
exports.isHorizontalConnector = isHorizontalConnector;
function isEdgedConnector(object) {
    return object.horizontalEdge !== null && object.verticalEdge !== null;
}
exports.isEdgedConnector = isEdgedConnector;
function isPointConnector(object) {
    return object.horizontalEdge === null && object.verticalEdge === null && object.intersectionPoint !== null;
}
exports.isPointConnector = isPointConnector;
function createConnectorType(horizontalEdgeStartPoint, intersectionPoint, verticalEdgeStartPoint) {
    // the connector is only a point
    if (horizontalEdgeStartPoint.row === verticalEdgeStartPoint.row && horizontalEdgeStartPoint.column === verticalEdgeStartPoint.column) {
        return { horizontalEdge: null, verticalEdge: null, intersectionPoint: intersectionPoint };
    }
    else if (horizontalEdgeStartPoint.row === verticalEdgeStartPoint.row) {
        // the connector is only horizontal
        const horizontalEdge = { start: horizontalEdgeStartPoint, end: verticalEdgeStartPoint };
        return { horizontalEdge: horizontalEdge, verticalEdge: null, intersectionPoint: null };
    }
    else if (horizontalEdgeStartPoint.column === verticalEdgeStartPoint.column) {
        // the connector is only vertical
        const verticalEdge = { start: verticalEdgeStartPoint, end: horizontalEdgeStartPoint };
        return { horizontalEdge: null, verticalEdge: verticalEdge, intersectionPoint: null };
    }
    else {
        const horizontalEdge = { start: horizontalEdgeStartPoint, end: intersectionPoint };
        const verticalEdge = { start: verticalEdgeStartPoint, end: intersectionPoint };
        return { horizontalEdge: horizontalEdge, verticalEdge: verticalEdge, intersectionPoint: intersectionPoint };
    }
}
exports.createConnectorType = createConnectorType;
class Connector {
    constructor(connectorType, lineStyle = LineStyle.Continuous, horizontalTipStyle = ConnectorTipStyle.Flat, verticalTipStyle = ConnectorTipStyle.Flat) {
        this._connectorType = connectorType;
        this._lineStyle = lineStyle;
        this._horizontalTipStyle = horizontalTipStyle;
        this._verticalTipStyle = verticalTipStyle;
    }
    static createByStartPoints(horizontalEdgeStartPoint, intersectionPoint, verticalEdgeStartPoint, lineStyle = LineStyle.Continuous, horizontalTipStyle = ConnectorTipStyle.Flat, verticalTipStyle = ConnectorTipStyle.Flat) {
        const connectorType = createConnectorType(horizontalEdgeStartPoint, intersectionPoint, verticalEdgeStartPoint);
        return new Connector(connectorType, lineStyle, horizontalTipStyle, verticalTipStyle);
    }
    get verticalEdge() {
        return this._connectorType.verticalEdge;
    }
    get horizontalEdge() {
        return this._connectorType.horizontalEdge;
    }
    get intersectionPoint() {
        return this._connectorType.intersectionPoint;
    }
    get connectorType() {
        return this._connectorType;
    }
    get lineStyle() {
        return this._lineStyle;
    }
    get horizontalTipStyle() {
        return this._horizontalTipStyle;
    }
    get verticalTipStyle() {
        return this._verticalTipStyle;
    }
}
exports.Connector = Connector;
(function (Connector) {
    class Builder {
        constructor(connectorType, lineStyle, horizontalTipStyle, verticalTipStyle) {
            this._connectorType = connectorType;
            this._lineStyle = lineStyle;
            this._horizontalTipStyle = horizontalTipStyle;
            this._verticalTipStyle = verticalTipStyle;
        }
        static from(connector) {
            return new Builder(connector.connectorType, connector.lineStyle, connector.horizontalTipStyle, connector.verticalTipStyle);
        }
        build() {
            return new Connector(this._connectorType, this._lineStyle, this._horizontalTipStyle, this._verticalTipStyle);
        }
        connectorType(value) {
            this._connectorType = value;
            return this;
        }
        lineStyle(value) {
            this._lineStyle = value;
            return this;
        }
        horizontalTipStyle(value) {
            this._horizontalTipStyle = value;
            return this;
        }
        verticalTipStyle(value) {
            this._verticalTipStyle = value;
            return this;
        }
    }
    Connector.Builder = Builder;
})(Connector = exports.Connector || (exports.Connector = {}));
//# sourceMappingURL=connector.js.map