"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const connector_1 = require("../entities/connector");
class ConnectorShape extends connector_1.Connector {
    constructor(id, connectorType, lineStyle = connector_1.LineStyle.Continuous, horizontalTipStyle = connector_1.ConnectorTipStyle.Flat, verticalTipStyle = connector_1.ConnectorTipStyle.Flat, editing = false) {
        super(connectorType, lineStyle, horizontalTipStyle, verticalTipStyle);
        this._editing = false;
        this._id = id;
        this._editing = editing;
    }
    static createShape(id, connectorType, lineStyle = connector_1.LineStyle.Continuous, horizontalTipStyle = connector_1.ConnectorTipStyle.Flat, verticalTipStyle = connector_1.ConnectorTipStyle.Flat) {
        return new ConnectorShape(id, connectorType, lineStyle, horizontalTipStyle, verticalTipStyle);
    }
    static createShapeByStartPoints(id, horizontalEdgeStartPoint, intersectionPoint, verticalEdgeStartPoint, lineStyle = connector_1.LineStyle.Continuous, horizontalTipStyle = connector_1.ConnectorTipStyle.Flat, verticalTipStyle = connector_1.ConnectorTipStyle.Flat) {
        const connector = connector_1.Connector.createByStartPoints(horizontalEdgeStartPoint, intersectionPoint, verticalEdgeStartPoint, lineStyle, horizontalTipStyle, verticalTipStyle);
        return new ConnectorShape(id, connector.connectorType, lineStyle, horizontalTipStyle, verticalTipStyle);
    }
    id() {
        return this._id;
    }
    editing() {
        return this._editing;
    }
    endEditing() {
        this._editing = false;
    }
    startEditing() {
        this._editing = true;
    }
}
exports.ConnectorShape = ConnectorShape;
(function (ConnectorShape) {
    class ShapeBuilder extends connector_1.Connector.Builder {
        constructor(id, connectorType, lineStyle, horizontalTipStyle, verticalTipStyle, editing = false) {
            super(connectorType, lineStyle, horizontalTipStyle, verticalTipStyle);
            this._editing = false;
            this._id = id;
            this._editing = editing;
        }
        static from(connectorShape) {
            return new ShapeBuilder(connectorShape.id(), connectorShape.connectorType, connectorShape.lineStyle, connectorShape.horizontalTipStyle, connectorShape.verticalTipStyle, connectorShape.editing());
        }
        build() {
            return new ConnectorShape(this._id, this._connectorType, this._lineStyle, this._horizontalTipStyle, this._verticalTipStyle, this._editing);
        }
        id(value) {
            this._id = value;
            return this;
        }
        editing(value) {
            this._editing = value;
            return this;
        }
    }
    ConnectorShape.ShapeBuilder = ShapeBuilder;
})(ConnectorShape = exports.ConnectorShape || (exports.ConnectorShape = {}));
//# sourceMappingURL=connector-shape.js.map